==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageChannelFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PackageChannelFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent<A>{
  public PackageChannelFluentImpl() {
  }
  public PackageChannelFluentImpl(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannel instance) {
    this.withCurrentCSV(instance.getCurrentCSV()); 
    this.withCurrentCSVDesc(instance.getCurrentCSVDesc()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String currentCSV;
  private io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder currentCSVDesc;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCurrentCSV() {
    return this.currentCSV;
  }
  public A withCurrentCSV(java.lang.String currentCSV) {
    this.currentCSV=currentCSV; return (A) this;
  }
  public java.lang.Boolean hasCurrentCSV() {
    return this.currentCSV != null;
  }
  
  /**
   * Method is deprecated. use withCurrentCSV instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentCSV(java.lang.String arg0) {
    return (A)withCurrentCSV(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCurrentCSVDesc instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription getCurrentCSVDesc() {
    return this.currentCSVDesc!=null?this.currentCSVDesc.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription buildCurrentCSVDesc() {
    return this.currentCSVDesc!=null?this.currentCSVDesc.build():null;
  }
  public A withCurrentCSVDesc(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription currentCSVDesc) {
    _visitables.get("currentCSVDesc").remove(this.currentCSVDesc);
    if (currentCSVDesc!=null){ this.currentCSVDesc= new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(currentCSVDesc); _visitables.get("currentCSVDesc").add(this.currentCSVDesc);} return (A) this;
  }
  public java.lang.Boolean hasCurrentCSVDesc() {
    return this.currentCSVDesc != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> withNewCurrentCSVDesc() {
    return new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluentImpl.CurrentCSVDescNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> withNewCurrentCSVDescLike(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
    return new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluentImpl.CurrentCSVDescNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editCurrentCSVDesc() {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc());
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editOrNewCurrentCSVDesc() {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc() != null ? getCurrentCSVDesc(): new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editOrNewCurrentCSVDescLike(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc() != null ? getCurrentCSVDesc(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PackageChannelFluentImpl that = (PackageChannelFluentImpl) o;
    if (currentCSV != null ? !currentCSV.equals(that.currentCSV) :that.currentCSV != null) return false;
    if (currentCSVDesc != null ? !currentCSVDesc.equals(that.currentCSVDesc) :that.currentCSVDesc != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(currentCSV,  currentCSVDesc,  name,  additionalProperties,  super.hashCode());
  }
  public class CurrentCSVDescNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluentImpl<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<N>> implements io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CurrentCSVDescNestedImpl(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(this, item);
    }
    CurrentCSVDescNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder builder;
    public N and() {
      return (N) PackageChannelFluentImpl.this.withCurrentCSVDesc(builder.build());
    }
    public N endCurrentCSVDesc() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.12.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageChannelFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PackageChannelFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent<A>{
  public PackageChannelFluentImpl() {
  }
  public PackageChannelFluentImpl(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannel instance) {
    this.withCurrentCSV(instance.getCurrentCSV()); 
    this.withCurrentCSVDesc(instance.getCurrentCSVDesc()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String currentCSV;
  private io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder currentCSVDesc;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCurrentCSV() {
    return this.currentCSV;
  }
  public A withCurrentCSV(java.lang.String currentCSV) {
    this.currentCSV=currentCSV; return (A) this;
  }
  public java.lang.Boolean hasCurrentCSV() {
    return this.currentCSV != null;
  }
  
  /**
   * Method is deprecated. use withCurrentCSV instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentCSV(java.lang.String arg0) {
    return (A)withCurrentCSV(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCurrentCSVDesc instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription getCurrentCSVDesc() {
    return this.currentCSVDesc!=null?this.currentCSVDesc.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription buildCurrentCSVDesc() {
    return this.currentCSVDesc!=null?this.currentCSVDesc.build():null;
  }
  public A withCurrentCSVDesc(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription currentCSVDesc) {
    _visitables.get("currentCSVDesc").remove(this.currentCSVDesc);
    if (currentCSVDesc!=null){ this.currentCSVDesc= new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(currentCSVDesc); _visitables.get("currentCSVDesc").add(this.currentCSVDesc);} return (A) this;
  }
  public java.lang.Boolean hasCurrentCSVDesc() {
    return this.currentCSVDesc != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> withNewCurrentCSVDesc() {
    return new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluentImpl.CurrentCSVDescNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> withNewCurrentCSVDescLike(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
    return new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluentImpl.CurrentCSVDescNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editCurrentCSVDesc() {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc());
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editOrNewCurrentCSVDesc() {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc() != null ? getCurrentCSVDesc(): new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<A> editOrNewCurrentCSVDescLike(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
    return withNewCurrentCSVDescLike(getCurrentCSVDesc() != null ? getCurrentCSVDesc(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PackageChannelFluentImpl that = (PackageChannelFluentImpl) o;
    if (currentCSV != null ? !currentCSV.equals(that.currentCSV) :that.currentCSV != null) return false;
    if (currentCSVDesc != null ? !currentCSVDesc.equals(that.currentCSVDesc) :that.currentCSVDesc != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(currentCSV,  currentCSVDesc,  name,  additionalProperties,  super.hashCode());
  }
  public class CurrentCSVDescNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionFluentImpl<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<N>> implements io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageChannelFluent.CurrentCSVDescNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CurrentCSVDescNestedImpl(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescription item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(this, item);
    }
    CurrentCSVDescNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.CSVDescriptionBuilder builder;
    public N and() {
      return (N) PackageChannelFluentImpl.this.withCurrentCSVDesc(builder.build());
    }
    public N endCurrentCSVDesc() {
      return and();
    }
    
  }
  
}
